import { PythonFunction } from "@aws-cdk/aws-lambda-python-alpha";
import { IVpc } from "aws-cdk-lib/aws-ec2";
import { Cluster } from "aws-cdk-lib/aws-ecs";
import { Bucket } from "aws-cdk-lib/aws-s3";
import { Queue } from "aws-cdk-lib/aws-sqs";
import { RemovalPolicy } from "aws-cdk-lib/core";
import { Construct } from "constructs";
import { FunctionSpec, ModuleSpec, PackyakSpec } from "./generated/spec.js";
import { Bindable } from "./bind.js";
import { INessieCatalog } from "./nessie/base-nessie-catalog.js";
import type { DNSConfiguration } from "./dns-configuration.js";
export interface LakeHouseProps {
    /**
     * The name of this Lake House.
     */
    readonly lakehouseName: string;
    /**
     * Source directory for the Packyak application.
     */
    readonly module: string;
    /**
     * The VPC to deploy the Packyak resources in to.
     *
     * @default - A new VPC is created.
     */
    readonly vpc?: IVpc;
    /**
     * The removal policy to apply to the Lake House.
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * The certificate to use for HTTPS.
     *
     * @default - Catalog is HTTP (insecure) only
     */
    readonly dns?: DNSConfiguration;
}
export declare class LakeHouse extends Construct {
    readonly spec: PackyakSpec;
    readonly vpc: IVpc;
    readonly cluster: Cluster;
    readonly catalog: INessieCatalog;
    readonly buckets: Bucket[];
    readonly queues: Queue[];
    readonly bucketIndex: {
        [bucket_id: string]: Bucket;
    };
    readonly queueIndex: {
        [queue_id: string]: Queue;
    };
    readonly functions: PythonFunction[];
    readonly functionIndex: {
        [function_id: string]: PythonFunction;
    };
    constructor(scope: Construct, id: string, props: LakeHouseProps);
    bind(target: Bindable, spec: ModuleSpec[] | FunctionSpec | ModuleSpec): void;
}
